# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: plugin.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'plugin.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cplugin.proto\x12\x05proto\x1a\x1cgoogle/protobuf/struct.proto\"2\n\x05\x45rror\x12\n\n\x02OK\x18\x02 \x01(\x08\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x0f\n\x07message\x18\x04 \x01(\t\"1\n\x0bInitRequest\x12\x14\n\x0c\x65vent_server\x18\x01 \x01(\r\x12\x0c\n\x04port\x18\x02 \x01(\r\"/\n\x0fOnCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06\x63onfig\x18\x02 \x01(\x0c\"/\n\x10OnCreateResponse\x12\x1b\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0c.proto.Error\"3\n\x10OnMessageRequest\x12\x0c\n\x04guid\x18\x01 \x01(\t\x12\x11\n\tinMessage\x18\x02 \x01(\x0c\"D\n\x11OnMessageResponse\x12\x12\n\noutMessage\x18\x01 \x01(\x0c\x12\x1b\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x0c.proto.Error\"\x1e\n\x0eOnCloseRequest\x12\x0c\n\x04guid\x18\x01 \x01(\t\".\n\x0fOnCloseResponse\x12\x1b\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0c.proto.Error\"0\n\x18PGetCapabilitiesResponse\x12\x14\n\x0c\x63\x61pabilities\x18\x01 \x01(\x04\"\x07\n\x05\x45mpty\";\n\x0c\x44\x65\x62ugRequest\x12\x0c\n\x04guid\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\x0c\"2\n\x14\x45mitFlowEventRequest\x12\x0c\n\x04guid\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"/\n\x10\x45mitInputRequest\x12\x0c\n\x04guid\x18\x01 \x01(\t\x12\r\n\x05input\x18\x02 \x01(\x0c\"?\n\x11\x45mitOutputRequest\x12\x0c\n\x04guid\x18\x01 \x01(\t\x12\x0e\n\x06output\x18\x02 \x01(\x0c\x12\x0c\n\x04port\x18\x03 \x01(\x05\"?\n\x10\x45mitErrorRequest\x12\x0c\n\x04guid\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\"6\n\x13GetVaultItemRequest\x12\x0f\n\x07vaultId\x18\x01 \x01(\t\x12\x0e\n\x06ItemId\x18\x02 \x01(\t\"=\n\x14GetVaultItemResponse\x12%\n\x04item\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\"D\n\x13SetVaultItemRequest\x12\x0f\n\x07vaultId\x18\x01 \x01(\t\x12\x0e\n\x06ItemId\x18\x02 \x01(\t\x12\x0c\n\x04\x44\x61ta\x18\x03 \x01(\x0c\"=\n\x14SetVaultItemResponse\x12%\n\x04item\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\"\'\n\x08Variable\x12\r\n\x05scope\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"7\n\x12GetVariableRequest\x12!\n\x08variable\x18\x01 \x01(\x0b\x32\x0f.proto.Variable\"=\n\x13GetVariableResponse\x12&\n\x05value\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\"_\n\x12SetVariableRequest\x12!\n\x08variable\x18\x01 \x01(\x0b\x32\x0f.proto.Variable\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\">\n\x14GetRobotInfoResponse\x12&\n\x05robot\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\"5\n\x11\x41ppRequestRequest\x12\x0f\n\x07request\x18\x01 \x01(\x0c\x12\x0f\n\x07timeout\x18\x02 \x01(\x05\"&\n\x12\x41ppRequestResponse\x12\x10\n\x08response\x18\x01 \x01(\x0c\"0\n\x13\x44ownloadFileRequest\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\"A\n\x12\x41ppDownloadRequest\x12\x11\n\tdirectory\x18\x01 \x01(\t\x12\x0c\n\x04\x66ile\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\"#\n\x13\x41ppDownloadResponse\x12\x0c\n\x04path\x18\x01 \x01(\t\",\n\x10\x41ppUploadRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\" \n\x11\x41ppUploadResponse\x12\x0b\n\x03url\x18\x01 \x01(\t\"\xb3\x01\n\x15GatewayRequestRequest\x12\x0e\n\x06method\x18\x01 \x01(\t\x12\x10\n\x08\x65ndpoint\x18\x02 \x01(\t\x12:\n\x07headers\x18\x03 \x03(\x0b\x32).proto.GatewayRequestRequest.HeadersEntry\x12\x0c\n\x04\x62ody\x18\x04 \x01(\t\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa7\x01\n\x16GatewayRequestResponse\x12\x12\n\nstatusCode\x18\x01 \x01(\x05\x12;\n\x07headers\x18\x02 \x03(\x0b\x32*.proto.GatewayRequestResponse.HeadersEntry\x12\x0c\n\x04\x62ody\x18\x03 \x01(\t\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x32\xa9\x02\n\x04Node\x12(\n\x04Init\x12\x12.proto.InitRequest\x1a\x0c.proto.Empty\x12;\n\x08OnCreate\x12\x16.proto.OnCreateRequest\x1a\x17.proto.OnCreateResponse\x12>\n\tOnMessage\x12\x17.proto.OnMessageRequest\x1a\x18.proto.OnMessageResponse\x12\x38\n\x07OnClose\x12\x15.proto.OnCloseRequest\x1a\x16.proto.OnCloseResponse\x12@\n\x0fGetCapabilities\x12\x0c.proto.Empty\x1a\x1f.proto.PGetCapabilitiesResponse2\xd7\x07\n\rRuntimeHelper\x12#\n\x05\x43lose\x12\x0c.proto.Empty\x1a\x0c.proto.Empty\x12*\n\x05\x44\x65\x62ug\x12\x13.proto.DebugRequest\x1a\x0c.proto.Empty\x12:\n\rEmitFlowEvent\x12\x1b.proto.EmitFlowEventRequest\x1a\x0c.proto.Empty\x12\x32\n\tEmitInput\x12\x17.proto.EmitInputRequest\x1a\x0c.proto.Empty\x12\x34\n\nEmitOutput\x12\x18.proto.EmitOutputRequest\x1a\x0c.proto.Empty\x12\x32\n\tEmitError\x12\x17.proto.EmitErrorRequest\x1a\x0c.proto.Empty\x12G\n\x0cGetVaultItem\x12\x1a.proto.GetVaultItemRequest\x1a\x1b.proto.GetVaultItemResponse\x12G\n\x0cSetVaultItem\x12\x1a.proto.SetVaultItemRequest\x1a\x1b.proto.SetVaultItemResponse\x12\x44\n\x0bGetVariable\x12\x19.proto.GetVariableRequest\x1a\x1a.proto.GetVariableResponse\x12\x36\n\x0bSetVariable\x12\x19.proto.SetVariableRequest\x1a\x0c.proto.Empty\x12\x39\n\x0cGetRobotInfo\x12\x0c.proto.Empty\x1a\x1b.proto.GetRobotInfoResponse\x12\x41\n\nAppRequest\x12\x18.proto.AppRequestRequest\x1a\x19.proto.AppRequestResponse\x12\x38\n\x0c\x44ownloadFile\x12\x1a.proto.DownloadFileRequest\x1a\x0c.proto.Empty\x12\x44\n\x0b\x41ppDownload\x12\x19.proto.AppDownloadRequest\x1a\x1a.proto.AppDownloadResponse\x12>\n\tAppUpload\x12\x17.proto.AppUploadRequest\x1a\x18.proto.AppUploadResponse\x12M\n\x0eGatewayRequest\x12\x1c.proto.GatewayRequestRequest\x1a\x1d.proto.GatewayRequestResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'plugin_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_GATEWAYREQUESTREQUEST_HEADERSENTRY']._loaded_options = None
  _globals['_GATEWAYREQUESTREQUEST_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_GATEWAYREQUESTRESPONSE_HEADERSENTRY']._loaded_options = None
  _globals['_GATEWAYREQUESTRESPONSE_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_ERROR']._serialized_start=53
  _globals['_ERROR']._serialized_end=103
  _globals['_INITREQUEST']._serialized_start=105
  _globals['_INITREQUEST']._serialized_end=154
  _globals['_ONCREATEREQUEST']._serialized_start=156
  _globals['_ONCREATEREQUEST']._serialized_end=203
  _globals['_ONCREATERESPONSE']._serialized_start=205
  _globals['_ONCREATERESPONSE']._serialized_end=252
  _globals['_ONMESSAGEREQUEST']._serialized_start=254
  _globals['_ONMESSAGEREQUEST']._serialized_end=305
  _globals['_ONMESSAGERESPONSE']._serialized_start=307
  _globals['_ONMESSAGERESPONSE']._serialized_end=375
  _globals['_ONCLOSEREQUEST']._serialized_start=377
  _globals['_ONCLOSEREQUEST']._serialized_end=407
  _globals['_ONCLOSERESPONSE']._serialized_start=409
  _globals['_ONCLOSERESPONSE']._serialized_end=455
  _globals['_PGETCAPABILITIESRESPONSE']._serialized_start=457
  _globals['_PGETCAPABILITIESRESPONSE']._serialized_end=505
  _globals['_EMPTY']._serialized_start=507
  _globals['_EMPTY']._serialized_end=514
  _globals['_DEBUGREQUEST']._serialized_start=516
  _globals['_DEBUGREQUEST']._serialized_end=575
  _globals['_EMITFLOWEVENTREQUEST']._serialized_start=577
  _globals['_EMITFLOWEVENTREQUEST']._serialized_end=627
  _globals['_EMITINPUTREQUEST']._serialized_start=629
  _globals['_EMITINPUTREQUEST']._serialized_end=676
  _globals['_EMITOUTPUTREQUEST']._serialized_start=678
  _globals['_EMITOUTPUTREQUEST']._serialized_end=741
  _globals['_EMITERRORREQUEST']._serialized_start=743
  _globals['_EMITERRORREQUEST']._serialized_end=806
  _globals['_GETVAULTITEMREQUEST']._serialized_start=808
  _globals['_GETVAULTITEMREQUEST']._serialized_end=862
  _globals['_GETVAULTITEMRESPONSE']._serialized_start=864
  _globals['_GETVAULTITEMRESPONSE']._serialized_end=925
  _globals['_SETVAULTITEMREQUEST']._serialized_start=927
  _globals['_SETVAULTITEMREQUEST']._serialized_end=995
  _globals['_SETVAULTITEMRESPONSE']._serialized_start=997
  _globals['_SETVAULTITEMRESPONSE']._serialized_end=1058
  _globals['_VARIABLE']._serialized_start=1060
  _globals['_VARIABLE']._serialized_end=1099
  _globals['_GETVARIABLEREQUEST']._serialized_start=1101
  _globals['_GETVARIABLEREQUEST']._serialized_end=1156
  _globals['_GETVARIABLERESPONSE']._serialized_start=1158
  _globals['_GETVARIABLERESPONSE']._serialized_end=1219
  _globals['_SETVARIABLEREQUEST']._serialized_start=1221
  _globals['_SETVARIABLEREQUEST']._serialized_end=1316
  _globals['_GETROBOTINFORESPONSE']._serialized_start=1318
  _globals['_GETROBOTINFORESPONSE']._serialized_end=1380
  _globals['_APPREQUESTREQUEST']._serialized_start=1382
  _globals['_APPREQUESTREQUEST']._serialized_end=1435
  _globals['_APPREQUESTRESPONSE']._serialized_start=1437
  _globals['_APPREQUESTRESPONSE']._serialized_end=1475
  _globals['_DOWNLOADFILEREQUEST']._serialized_start=1477
  _globals['_DOWNLOADFILEREQUEST']._serialized_end=1525
  _globals['_APPDOWNLOADREQUEST']._serialized_start=1527
  _globals['_APPDOWNLOADREQUEST']._serialized_end=1592
  _globals['_APPDOWNLOADRESPONSE']._serialized_start=1594
  _globals['_APPDOWNLOADRESPONSE']._serialized_end=1629
  _globals['_APPUPLOADREQUEST']._serialized_start=1631
  _globals['_APPUPLOADREQUEST']._serialized_end=1675
  _globals['_APPUPLOADRESPONSE']._serialized_start=1677
  _globals['_APPUPLOADRESPONSE']._serialized_end=1709
  _globals['_GATEWAYREQUESTREQUEST']._serialized_start=1712
  _globals['_GATEWAYREQUESTREQUEST']._serialized_end=1891
  _globals['_GATEWAYREQUESTREQUEST_HEADERSENTRY']._serialized_start=1845
  _globals['_GATEWAYREQUESTREQUEST_HEADERSENTRY']._serialized_end=1891
  _globals['_GATEWAYREQUESTRESPONSE']._serialized_start=1894
  _globals['_GATEWAYREQUESTRESPONSE']._serialized_end=2061
  _globals['_GATEWAYREQUESTRESPONSE_HEADERSENTRY']._serialized_start=1845
  _globals['_GATEWAYREQUESTRESPONSE_HEADERSENTRY']._serialized_end=1891
  _globals['_NODE']._serialized_start=2064
  _globals['_NODE']._serialized_end=2361
  _globals['_RUNTIMEHELPER']._serialized_start=2364
  _globals['_RUNTIMEHELPER']._serialized_end=3347
# @@protoc_insertion_point(module_scope)
